==> haskell-simple-sendfile-0.2.32-165-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-simple-sendfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 simple-sendfile
version:              0.2.32
visibility:           public
id:                   simple-sendfile-0.2.32-IHrbXL0LLWsEZrh5riMJx5
key:                  simple-sendfile-0.2.32-IHrbXL0LLWsEZrh5riMJx5
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Cross platform library for the sendfile system call
description:
    Cross platform library for the sendfile system call.
    This library tries to call minimum system calls which
    are the bottleneck of web servers.

category:             Network
abi:                  03b514cc1deba2ca9f9328346cc21bb3
exposed:              True
exposed-modules:      Network.Sendfile System.Linux.Sendfile
hidden-modules:       Network.Sendfile.Types Network.Sendfile.Linux
import-dirs:          /usr/lib/ghc-9.4.8/site-local/simple-sendfile-0.2.32
library-dirs:         /usr/lib/ghc-9.4.8/site-local/simple-sendfile-0.2.32
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/simple-sendfile-0.2.32
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-simple-sendfile
hs-libraries:         HSsimple-sendfile-0.2.32-IHrbXL0LLWsEZrh5riMJx5
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-BMQQjwbPvFR57Ka0tgIiy2 unix-2.7.3

haddock-interfaces:
    /usr/share/doc/haskell-simple-sendfile/html/simple-sendfile.haddock

haddock-html:         /usr/share/doc/haskell-simple-sendfile/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-simple-sendfile-0.2.32-184-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-simple-sendfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 simple-sendfile
version:              0.2.32
visibility:           public
id:                   simple-sendfile-0.2.32-13egQs09l9jGdPZ9NlDEZJ
key:                  simple-sendfile-0.2.32-13egQs09l9jGdPZ9NlDEZJ
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Cross platform library for the sendfile system call
description:
    Cross platform library for the sendfile system call.
    This library tries to call minimum system calls which
    are the bottleneck of web servers.

category:             Network
abi:                  a5369f41d803c6d4dd98ad1c61159019
exposed:              True
exposed-modules:      Network.Sendfile System.Linux.Sendfile
hidden-modules:       Network.Sendfile.Types Network.Sendfile.Linux
import-dirs:          /usr/lib/ghc-9.4.8/site-local/simple-sendfile-0.2.32
library-dirs:         /usr/lib/ghc-9.4.8/site-local/simple-sendfile-0.2.32
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/simple-sendfile-0.2.32
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-simple-sendfile
hs-libraries:         HSsimple-sendfile-0.2.32-13egQs09l9jGdPZ9NlDEZJ
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-2g2oEkgQCahBaM3HvlpVNW unix-2.7.3

haddock-interfaces:
    /usr/share/doc/haskell-simple-sendfile/html/simple-sendfile.haddock

haddock-html:         /usr/share/doc/haskell-simple-sendfile/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
